@@ -74,6 +74,18 @@ class KatPod(KatRes):
   def image(self, index=0) -> str:
     return self.container and self.container(index).image
 
+  def rs(self):
+    ref = self.owner_ref('ReplicaSet')
+    if ref:
+      from k8kat.res.rs.kat_rs import KatRs
+      return KatRs.find(ref.name, self.ns)
+    else:
+      return None
+
+  def dep(self):
+    rs = self.rs()
+    return rs.dep() if rs else None
+
 # --
 # --
 # --
